@@ -1,3 +1,11 @@
+from python_framework import StaticConverter
+
+try:
+    import ModelConstant
+except:
+    from queue_manager_api.api.src.constant import ModelConstant
+
+
 class MessageRequestDto:
     def __init__(self,
         key = None,
@@ -27,6 +35,7 @@ class MessageResponseDto:
         self.content = content
         self.history = history
 
+
 class MessageCreationRequestDto:
     def __init__(self,
         key = None,
@@ -56,3 +65,22 @@ class MessageQueryRequestDto:
         self.key = key
         self.queueKey = queueKey
         self.groupKey = groupKey
+
+
+class MessageQueryResponseDto:
+    def __init__(self,
+        key = None,
+        queueKey = None,
+        groupKey = None,
+        content = None,
+        history = None,
+        status = None,
+        state = None
+    ):
+        self.key = key
+        self.queueKey = queueKey
+        self.groupKey = groupKey
+        self.content = content
+        self.history = history
+        self.status = StaticConverter.getValueOrDefault(status, ModelConstant.DEFAULT_STATUS)
+        self.state = StaticConverter.getValueOrDefault(state, ModelConstant.DEFAULT_STATE)
