@@ -1,4 +1,4 @@
-from python_framework import ConverterStatic
+from python_framework import StaticConverter
 
 try:
     import SubscriptionConstant
@@ -18,8 +18,8 @@ class SubscriptionRequestDto:
         self.key = key
         self.url = url
         self.onErrorUrl = onErrorUrl
-        self.maxTries = ConverterStatic.getValueOrDefault(maxTries, SubscriptionConstant.DEFAULT_MAX_TRIES)
-        self.backOff = ConverterStatic.getValueOrDefault(backOff, SubscriptionConstant.DEFAULT_BACKOFF)
+        self.maxTries = StaticConverter.getValueOrDefault(maxTries, SubscriptionConstant.DEFAULT_MAX_TRIES)
+        self.backOff = StaticConverter.getValueOrDefault(backOff, SubscriptionConstant.DEFAULT_BACKOFF)
         self.queue = queue
 
 
@@ -36,6 +36,6 @@ class SubscriptionResponseDto:
         self.key = key
         self.url = url
         self.onErrorUrl = onErrorUrl
-        self.maxTries = ConverterStatic.getValueOrDefault(maxTries, SubscriptionConstant.DEFAULT_MAX_TRIES)
-        self.backOff = ConverterStatic.getValueOrDefault(backOff, SubscriptionConstant.DEFAULT_BACKOFF)
+        self.maxTries = StaticConverter.getValueOrDefault(maxTries, SubscriptionConstant.DEFAULT_MAX_TRIES)
+        self.backOff = StaticConverter.getValueOrDefault(backOff, SubscriptionConstant.DEFAULT_BACKOFF)
         self.queue = queue
